@@ -246,6 +246,10 @@ public:
     void removeAudioStreamEffect(int streamIndex, QString effectName);
     /** @brief Get the list of audio stream effects for a defined stream. */
     QStringList getAudioStreamEffect(int streamIndex) const override;
+    /** @brief Calculate the folder's hash (based on the files it contains). */
+    static const QByteArray getFolderHash(QDir dir);
+    /** @brief Check if the clip is included in timeline and reset its occurences on producer reload. */
+    void updateTimelineOnReload();
 
 protected:
     friend class ClipModel;
@@ -290,7 +294,9 @@ private:
     QFuture<void> m_thumbThread;
     QList<int> m_requestedThumbs;
     const QString geometryWithOffset(const QString &data, int offset);
-
+    QMap <QString, QByteArray> m_audioLevels;
+    /** @brief If true, all timeline occurences of this clip will be replaced from a fresh producer on reload. */
+    bool m_resetTimelineOccurences;
     // This is a helper function that creates the disabled producer. This is a clone of the original one, with audio and video disabled
     void createDisabledMasterProducer();
 
