@@ -23,6 +23,7 @@
 #include "kdenlivesettings.h"
 #include "kthumb.h"
 #include "titler/titlewidget.h"
+#include "bin/projectclip.h"
 
 #include <KMessageBox>
 #include <KRecentDirs>
@@ -123,6 +124,7 @@ bool DocumentChecker::hasErrorInClips()
     }
 
     QDomNodeList documentProducers = m_doc.elementsByTagName(QStringLiteral("producer"));
+    QDomNodeList entries = m_doc.elementsByTagName(QStringLiteral("entry"));
     QDomElement profile = baseElement.firstChildElement(QStringLiteral("profile"));
     bool hdProfile = true;
     if (!profile.isNull()) {
@@ -137,6 +139,7 @@ bool DocumentChecker::hasErrorInClips()
     m_safeImages.clear();
     m_safeFonts.clear();
     m_missingFonts.clear();
+    m_changedClips.clear();
     max = documentProducers.count();
     QStringList verifiedPaths;
     QStringList missingPaths;
@@ -149,6 +152,22 @@ bool DocumentChecker::hasErrorInClips()
         if (!service.startsWith(QLatin1String("avformat")) && !serviceToCheck.contains(service)) {
             continue;
         }
+        if (Xml::getXmlProperty(e, QStringLiteral("kdenlive:id")).isEmpty()) {
+            // This should not happen, try to recover the producer id
+            int max2 = entries.count();
+            QString producerName = e.attribute(QStringLiteral("id"));
+            for (int j = 0; j < max2; j++) {
+                QDomElement e2 = entries.item(j).toElement();
+                if (e2.attribute(QStringLiteral("producer")) == producerName) {
+                    // Matche found
+                    QString entryName = Xml::getXmlProperty(e2, QStringLiteral("kdenlive:id"));
+                    if (!entryName.isEmpty()) {
+                        Xml::setXmlProperty(e, QStringLiteral("kdenlive:id"), entryName);
+                        break;
+                    }
+                }
+            }
+        }
         if (service == QLatin1String("qtext")) {
             QString text = Xml::getXmlProperty(e, QStringLiteral("text"));
             if (text == QLatin1String("INVALID")) {
@@ -223,6 +242,7 @@ bool DocumentChecker::hasErrorInClips()
 
         QString proxy = Xml::getXmlProperty(e, QStringLiteral("kdenlive:proxy"));
         if (proxy.length() > 1) {
+            bool proxyFound = true;
             if (QFileInfo(proxy).isRelative()) {
                 proxy.prepend(root);
             }
@@ -240,7 +260,7 @@ bool DocumentChecker::hasErrorInClips()
                     }
                 }
                 if (!fixed) {
-                    missingProxies.append(e);
+                    proxyFound = false;
                 }
             }
             QString original = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
@@ -253,9 +273,16 @@ bool DocumentChecker::hasErrorInClips()
                 original = QFileInfo(original).absolutePath();
             }
             if (!QFile::exists(original)) {
-                // clip has proxy but original clip is missing
-                missingSources.append(e);
+                if (!proxyFound) {
+                    // Neither proxy nor original file found
+                    m_missingClips.append(e);
+                } else {
+                    // clip has proxy but original clip is missing
+                    missingSources.append(e);
+                }
                 missingPaths.append(original);
+            } else if (!proxyFound) {
+                missingProxies.append(e);
             }
             verifiedPaths.append(resource);
             continue;
@@ -274,6 +301,20 @@ bool DocumentChecker::hasErrorInClips()
             }
         }
         if (!QFile::exists(resource)) {
+            if (service == QLatin1String("timewarp") && proxy == QLatin1String("-")) {
+                // In some corrupted cases, clips with speed effect kept a reference to proxy clip in warp_resource
+                QString original = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
+                if (QFileInfo(original).isRelative()) {
+                    original.prepend(root);
+                }
+                if (original != resource && QFile::exists(original)) {
+                    // Fix timewarp producer
+                    Xml::setXmlProperty(e, QStringLiteral("warp_resource"), original);
+                    Xml::setXmlProperty(e, QStringLiteral("resource"), Xml::getXmlProperty(e, QStringLiteral("warp_speed")) + QStringLiteral(":") + original);
+                    verifiedPaths.append(original);
+                    continue;
+                }
+            }
             // Missing clip found, make sure to omit timeline preview
             if (QFileInfo(resource).absolutePath().endsWith(QString("/%1/preview").arg(documentid))) {
                 // This is a timeline preview missing chunk, ignore
@@ -281,6 +322,17 @@ bool DocumentChecker::hasErrorInClips()
                 m_missingClips.append(e);
                 missingPaths.append(resource);
             }
+        } else if (service.startsWith(QLatin1String("avformat"))) {
+            // Check if file changed
+            const QByteArray hash = Xml::getXmlProperty(e, "kdenlive:file_hash").toLatin1();
+            if (!hash.isEmpty()) {
+                const QByteArray fileData = ProjectClip::calculateHash(resource).first.toHex();
+                if (hash != fileData) {
+                    // Clip was changed, notify and trigger clip reload
+                    Xml::removeXmlProperty(e, "kdenlive:file_hash");
+                    m_changedClips.append(resource);
+                }
+            }
         }
         // Make sure we don't query same path twice
         verifiedPaths.append(resource);
@@ -410,7 +462,7 @@ bool DocumentChecker::hasErrorInClips()
         }
     }
     if (m_missingClips.isEmpty() && missingLumas.isEmpty() && missingProxies.isEmpty() && missingSources.isEmpty() && m_missingFonts.isEmpty() &&
-        m_missingFilters.isEmpty()) {
+        m_missingFilters.isEmpty() && m_changedClips.isEmpty()) {
         return false;
     }
 
@@ -434,8 +486,14 @@ bool DocumentChecker::hasErrorInClips()
         ClipType::ProducerType type;
         int status = CLIPMISSING;
         const QString service = Xml::getXmlProperty(e, QStringLiteral("mlt_service"));
-        QString resource =
+        QString resource;
+        QString proxy = Xml::getXmlProperty(e, QStringLiteral("kdenlive:proxy"));
+        if (proxy.length() > 1) {
+            resource = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
+        } else {
+            resource =
             service == QLatin1String("timewarp") ? Xml::getXmlProperty(e, QStringLiteral("warp_resource")) : Xml::getXmlProperty(e, QStringLiteral("resource"));
+        }
         bool slideshow = resource.contains(QStringLiteral("/.all.")) || resource.contains(QLatin1Char('?')) || resource.contains(QLatin1Char('%'));
         if (service.startsWith(QLatin1String("avformat")) || service == QLatin1String("framebuffer") ||
             service == QLatin1String("timewarp")) {
@@ -522,11 +580,20 @@ bool DocumentChecker::hasErrorInClips()
         QString clipType = i18n("Title Font");
         QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << clipType);
         item->setData(0, statusRole, CLIPPLACEHOLDER);
-        item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-warning")));
+        item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-information")));
         QString newft = QFontInfo(QFont(font)).family();
         item->setText(1, i18n("%1 will be replaced by %2", font, newft));
         item->setData(0, typeRole, TITLE_FONT_ELEMENT);
     }
+    
+    for (const QString &url : qAsConst(m_changedClips)) {
+        QString clipType = i18n("Modified Clips");
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << clipType);
+        item->setData(0, statusRole, CLIPPLACEHOLDER);
+        item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-information")));
+        item->setText(1, i18n("Clip %1 will be reloaded", url));
+        item->setData(0, typeRole, TITLE_FONT_ELEMENT);
+    }
 
     QString infoLabel;
     if (!m_missingClips.isEmpty()) {
@@ -564,6 +631,13 @@ bool DocumentChecker::hasErrorInClips()
         infoLabel.append(i18np("The project file contains a missing clip, you can still work with its proxy.",
                                "The project file contains %1 missing clips, you can still work with their proxies.", missingSources.count()));
     }
+    if (!m_changedClips.isEmpty()) {
+        if (!infoLabel.isEmpty()) {
+            infoLabel.append(QStringLiteral("\n"));
+        }
+        infoLabel.append(i18np("The project file contains one modified clip, it will be reloaded.",
+                               "The project file contains %1 modified clips, they will be reloaded.", m_changedClips.count()));
+    }
     if (!infoLabel.isEmpty()) {
         m_ui.infoLabel->setText(infoLabel);
     } else {
@@ -576,16 +650,6 @@ bool DocumentChecker::hasErrorInClips()
 
     // Check missing proxies
     max = missingProxies.count();
-    if (max > 0) {
-        QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << i18n("Proxy clip"));
-        item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-warning")));
-        item->setText(
-            1, i18np("%1 missing proxy clip, will be recreated on project opening", "%1 missing proxy clips, will be recreated on project opening", max));
-        // item->setData(0, hashRole, e.attribute("file_hash"));
-        item->setData(0, statusRole, PROXYMISSING);
-        item->setToolTip(0, i18n("Missing proxy"));
-    }
-
     for (int i = 0; i < max; ++i) {
         QDomElement e = missingProxies.at(i).toElement();
         QString realPath = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
@@ -602,22 +666,15 @@ bool DocumentChecker::hasErrorInClips()
             mltProd = documentProducers.at(j).toElement();
             QString prodId = mltProd.attribute(QStringLiteral("id"));
             QString parentId = Xml::getXmlProperty(mltProd, QStringLiteral("kdenlive:id"));
-            bool slowmotion = false;
-            if (parentId.startsWith(QLatin1String("slowmotion"))) {
-                slowmotion = true;
-                parentId = parentId.section(QLatin1Char(':'), 1, 1);
-            }
-            if (parentId.contains(QLatin1Char('_'))) {
-                parentId = parentId.section(QLatin1Char('_'), 0, 0);
-            }
             if (parentId == id) {
                 // Hit, we must replace url
-                QString suffix;
-                if (slowmotion) {
-                    QString resource = Xml::getXmlProperty(mltProd, QStringLiteral("resource"));
-                    suffix = QLatin1Char('?') + resource.section(QLatin1Char('?'), -1);
+                QString prefix;
+                if (Xml::getXmlProperty(mltProd, QStringLiteral("mlt_service")) == QLatin1String("timewarp")) {
+                    prefix = Xml::getXmlProperty(mltProd, QStringLiteral("warp_speed"));
+                    prefix.append(QLatin1Char(':'));
+                    Xml::setXmlProperty(mltProd, QStringLiteral("warp_resource"), prefix + realPath);
                 }
-                Xml::setXmlProperty(mltProd, QStringLiteral("resource"), realPath + suffix);
+                Xml::setXmlProperty(mltProd, QStringLiteral("resource"), prefix + realPath);
                 Xml::setXmlProperty(mltProd, QStringLiteral("kdenlive:proxy"), QStringLiteral("-"));
                 if (missingPaths.contains(realPath)) {
                     // Proxy AND source missing
@@ -628,6 +685,16 @@ bool DocumentChecker::hasErrorInClips()
         }
     }
 
+    if (max > 0) {
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_ui.treeWidget, QStringList() << i18n("Proxy clip"));
+        item->setIcon(0, QIcon::fromTheme(QStringLiteral("dialog-warning")));
+        item->setText(
+            1, i18np("%1 missing proxy clip, will be recreated on project opening", "%1 missing proxy clips, will be recreated on project opening", max));
+        // item->setData(0, hashRole, e.attribute("file_hash"));
+        item->setData(0, statusRole, PROXYMISSING);
+        item->setToolTip(0, i18n("Missing proxy"));
+    }
+
     if (max > 0) {
         // original doc was modified
         m_doc.documentElement().setAttribute(QStringLiteral("modified"), 1);
@@ -646,6 +713,9 @@ bool DocumentChecker::hasErrorInClips()
             QDomElement e = missingSources.at(i).toElement();
             QString realPath = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
             // Tell Kdenlive the source is missing
+            if (QFileInfo(realPath).isRelative()) {
+                realPath.prepend(root);
+            }
             e.setAttribute(QStringLiteral("_missingsource"), QStringLiteral("1"));
             QTreeWidgetItem *subitem = new QTreeWidgetItem(item, QStringList() << i18n("Source clip"));
             // qCDebug(KDENLIVE_LOG)<<"// Adding missing source clip: "<<realPath;
@@ -1027,19 +1097,22 @@ void DocumentChecker::fixProxyClip(const QString &id, const QString &oldUrl, con
             // This is probably an old project file
             QString sourceId = e.attribute(QStringLiteral("id"));
             parentId = sourceId.section(QLatin1Char('_'), 0, 0);
-            if (parentId.startsWith(QLatin1String("slowmotion"))) {
-                parentId = parentId.section(QLatin1Char(':'), 1, 1);
-            }
         }
         if (parentId == id) {
             // Fix clip
             QString resource = Xml::getXmlProperty(e, QStringLiteral("resource"));
-            // TODO: Slowmmotion clips
-            if (resource.contains(QRegExp(QStringLiteral("\\?[0-9]+\\.[0-9]+(&amp;strobe=[0-9]+)?$")))) {
-                // fixedResource.append(QLatin1Char('?') + resource.section(QLatin1Char('?'), -1));
+            bool timewarp = false;
+            if (Xml::getXmlProperty(e, QStringLiteral("mlt_service")) == QLatin1String("timewarp")) {
+                timewarp = true;
+                resource = Xml::getXmlProperty(e, QStringLiteral("warp_resource"));
             }
             if (resource == oldUrl) {
-                Xml::setXmlProperty(e, QStringLiteral("resource"), newUrl);
+                if (timewarp) {
+                    Xml::setXmlProperty(e, QStringLiteral("resource"), Xml::getXmlProperty(e, QStringLiteral("warp_speed")) + ":" + newUrl);
+                    Xml::setXmlProperty(e, QStringLiteral("warp_resource"), newUrl);
+                } else {
+                    Xml::setXmlProperty(e, QStringLiteral("resource"), newUrl);
+                }
             }
             if (!Xml::getXmlProperty(e, QStringLiteral("kdenlive:proxy")).isEmpty()) {
                 // Only set originalurl on master producer
@@ -1063,24 +1136,23 @@ void DocumentChecker::fixSourceClipItem(QTreeWidgetItem *child, const QDomNodeLi
                 // This is probably an old project file
                 QString sourceId = e.attribute(QStringLiteral("id"));
                 parentId = sourceId.section(QLatin1Char('_'), 0, 0);
-                if (parentId.startsWith(QLatin1String("slowmotion"))) {
-                    parentId = parentId.section(QLatin1Char(':'), 1, 1);
-                }
             }
             if (parentId == id) {
                 // Fix clip
                 QString resource = Xml::getXmlProperty(e, QStringLiteral("resource"));
                 QString fixedResource = child->text(1);
-                if (resource.contains(QRegExp(QStringLiteral("\\?[0-9]+\\.[0-9]+(&amp;strobe=[0-9]+)?$")))) {
-                    fixedResource.append(QLatin1Char('?') + resource.section(QLatin1Char('?'), -1));
-                }
                 if (!Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl")).isEmpty()) {
                     // Only set originalurl on master producer
                     Xml::setXmlProperty(e, QStringLiteral("kdenlive:originalurl"), fixedResource);
                 }
                 if (m_missingProxyIds.contains(parentId)) {
                     // Proxy is also missing, replace resource
-                    Xml::setXmlProperty(e, QStringLiteral("resource"), fixedResource);
+                    if (Xml::getXmlProperty(e, QStringLiteral("mlt_service")) == QLatin1String("timewarp")) {
+                        Xml::setXmlProperty(e, QStringLiteral("warp_resource"), fixedResource);
+                        Xml::setXmlProperty(e, QStringLiteral("resource"), Xml::getXmlProperty(e, QStringLiteral("warp_speed")) + ":" + fixedResource);
+                    } else {
+                        Xml::setXmlProperty(e, QStringLiteral("resource"), fixedResource);
+                    }
                 }
             }
         }
@@ -1105,9 +1177,6 @@ void DocumentChecker::fixClipItem(QTreeWidgetItem *child, const QDomNodeList &pr
                     // This is probably an old project file
                     QString sourceId = e.attribute(QStringLiteral("id"));
                     parentId = sourceId.section(QLatin1Char('_'), 0, 0);
-                    if (parentId.startsWith(QLatin1String("slowmotion"))) {
-                        parentId = parentId.section(QLatin1Char(':'), 1, 1);
-                    }
                 }
                 if (parentId == id) {
                     // Fix clip
@@ -1143,14 +1212,20 @@ void DocumentChecker::fixClipItem(QTreeWidgetItem *child, const QDomNodeList &pr
                     QString service = getProperty(e, QStringLiteral("mlt_service"));
                     QString updatedResource = fixedResource;
                     qDebug()<<"===== UPDATING RESOURCE FOR: "<<id<<": "<<resource<<" > "<<fixedResource;
-                    if (resource.contains(QRegExp(QStringLiteral("\\?[0-9]+\\.[0-9]+(&amp;strobe=[0-9]+)?$")))) {
-                        updatedResource.append(QLatin1Char('?') + resource.section(QLatin1Char('?'), -1));
-                    }
                     if (service == QLatin1String("timewarp")) {
                         updateProperty(e, QStringLiteral("warp_resource"), updatedResource);
                         updatedResource.prepend(getProperty(e, QStringLiteral("warp_speed")) + QLatin1Char(':'));
                     }
+                    if (!Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl")).isEmpty()) {
+                        // Only set originalurl on master producer
+                        Xml::setXmlProperty(e, QStringLiteral("kdenlive:originalurl"), fixedResource);
+                    }
                     updateProperty(e, QStringLiteral("resource"), updatedResource);
+                    QString proxy = Xml::getXmlProperty(e, QStringLiteral("kdenlive:proxy"));
+                    if (proxy.length() > 1) {
+                        // Disable proxy
+                        updateProperty(e, QStringLiteral("kdenlive:proxy"), QStringLiteral("-"));
+                    }
                 }
             }
         }
