@@ -113,6 +113,10 @@ bool AudioThumbJob::computeWithMlt()
 
 bool AudioThumbJob::computeWithFFMPEG()
 {
+    if (!KdenliveSettings::audiothumbnails()) {
+        // We only wanted the thumb generation
+        return m_done;
+    }
     QString filePath = m_prod->get("kdenlive:originalurl");
     if (filePath.isEmpty() || !QFile::exists(filePath)) {
         filePath = m_prod->get("resource");
@@ -214,8 +218,10 @@ bool AudioThumbJob::computeWithFFMPEG()
             if (m_ffmpegProcess) {
                 disconnect(m_ffmpegProcess.get(), &QProcess::readyReadStandardOutput, this, &AudioThumbJob::updateFfmpegProgress);
                 m_ffmpegProcess->kill();
-                m_successful = false;
             }
+            m_audioLevels.clear();
+            m_done = true;
+            m_successful = false;
         });
         m_ffmpegProcess->start(KdenliveSettings::ffmpegpath(), args);
         m_ffmpegProcess->waitForFinished(-1);
@@ -249,7 +255,11 @@ bool AudioThumbJob::computeWithFFMPEG()
                 intraOffset = offset / 10;
             }
             long maxLevel = 1;
-            QVector <long> ffmpegLevels;
+            if (!m_successful) {
+                m_done = true;
+                return true;
+            }
+            std::vector <long> ffmpegLevels;
             for (int i = 0; i < m_lengthInFrames; i++) {
                 channelsData.resize((size_t)rawChannels.size());
                 std::fill(channelsData.begin(), channelsData.end(), 0);
@@ -261,18 +271,25 @@ bool AudioThumbJob::computeWithFFMPEG()
                         channelsData[k] += abs(rawChannels[k][pos + j]);
                     }
                 }
+                steps = qMax(steps, 1);
                 for (long &k : channelsData) {
-                    if (steps != 0) {
-                        k /= steps;
+                    if (!m_successful) {
+                        break;
                     }
+                    k /= steps;
                     maxLevel = qMax(k, maxLevel);
-                    ffmpegLevels << k;
                 }
+                
                 int p = 80 + (i * 20 / m_lengthInFrames);
                 if (p != progress) {
                     emit jobProgress(p);
                     progress = p;
                 }
+                ffmpegLevels.insert(ffmpegLevels.end(), channelsData.begin(), channelsData.end());
+            }
+            if (!m_successful) {
+                m_done = true;
+                return true;
             }
             for (long &v : ffmpegLevels) {
                 m_audioLevels << (uint8_t) (255 * v / maxLevel);
@@ -296,7 +313,7 @@ void AudioThumbJob::updateFfmpegProgress()
     if (m_ffmpegProcess == nullptr) {
         return;
     }
-    QString result = m_ffmpegProcess->readAllStandardOutput();
+    const QString result = m_ffmpegProcess->readAllStandardOutput();
     const QStringList lines = result.split(QLatin1Char('\n'));
     for (const QString &data : lines) {
         if (data.startsWith(QStringLiteral("out_time_ms"))) {
@@ -334,7 +351,12 @@ bool AudioThumbJob::startJob()
     }
     m_lengthInFrames = m_prod->get_length(); // Multiply this if we want more than 1 sample per frame
     int thumbResolution = 3000;
-    
+    if (m_lengthInFrames == INT_MAX) {
+        // This is a broken file or live feed, don't attempt to generate audio thumbnails
+        m_done = true;
+        m_successful = false;
+        return false;
+    }
     // Increase audio thumb resolution for longer clips to get a better resolution
     if (m_lengthInFrames > 10000) {
         // More than 10 minutes at 25fps
@@ -346,7 +368,6 @@ bool AudioThumbJob::startJob()
         }
     }
     m_thumbSize = QSize(thumbResolution, 1000 / pCore->getCurrentDar());
-
     m_frequency = m_binClip->audioInfo()->samplingRate();
     m_frequency = m_frequency <= 0 ? 48000 : m_frequency;
 
@@ -375,10 +396,12 @@ bool AudioThumbJob::startJob()
                 ok = computeWithMlt();
             }
         }
+        m_ffmpegProcess.reset();
         Q_ASSERT(ok == m_done);
         if (!m_successful) {
             // Job was aborted
             m_done = true;
+            m_audioLevels.clear();
             return false;
         }
 
@@ -418,7 +441,6 @@ bool AudioThumbJob::startJob()
 bool AudioThumbJob::commitResult(Fun &undo, Fun &redo)
 {
     Q_ASSERT(!m_resultConsumed);
-    m_ffmpegProcess.reset();
     if (!m_done) {
         qDebug() << "ERROR: Trying to consume invalid results";
         return false;
