@@ -42,9 +42,9 @@ class MonitorProxy : public QObject
     Q_PROPERTY(int seekFinished MEMBER m_seekFinished NOTIFY seekFinishedChanged)
     Q_PROPERTY(int zoneIn READ zoneIn WRITE setZoneIn NOTIFY zoneChanged)
     Q_PROPERTY(int zoneOut READ zoneOut WRITE setZoneOut NOTIFY zoneChanged)
-    Q_PROPERTY(int rulerHeight READ rulerHeight NOTIFY rulerHeightChanged)
+    Q_PROPERTY(int rulerHeight READ rulerHeight WRITE setRulerHeight NOTIFY rulerHeightChanged)
     Q_PROPERTY(QString markerComment READ markerComment NOTIFY markerCommentChanged)
-    Q_PROPERTY(QUrl audioThumb MEMBER m_audioThumb NOTIFY audioThumbChanged)
+    Q_PROPERTY(QList <QUrl> audioThumb MEMBER m_audioThumb NOTIFY audioThumbChanged)
     Q_PROPERTY(int overlayType READ overlayType WRITE setOverlayType NOTIFY overlayTypeChanged)
     /** @brief: Returns true if current clip in monitor has Audio and Video
      * */
@@ -52,6 +52,7 @@ class MonitorProxy : public QObject
     /** @brief: Contains the name of clip currently displayed in monitor
      * */
     Q_PROPERTY(QString clipName MEMBER m_clipName NOTIFY clipNameChanged)
+    Q_PROPERTY(QString clipStream MEMBER m_clipStream NOTIFY clipStreamChanged)
     /** @brief: Contains the name of clip currently displayed in monitor
      * */
     Q_PROPERTY(int clipType MEMBER m_clipType NOTIFY clipTypeChanged)
@@ -70,6 +71,7 @@ public:
      * */
     int getPosition() const;
     Q_INVOKABLE bool setPosition(int pos);
+    Q_INVOKABLE void seek(int delta, uint modifiers);
     void positionFromConsumer(int pos, bool playing);
     void setMarkerComment(const QString &comment);
     int zoneIn() const;
@@ -90,7 +92,9 @@ public:
     Q_INVOKABLE double fps() const;
     QPoint profile();
     void setClipProperties(int clipId, ClipType::ProducerType type, bool hasAV, const QString clipName);
-    void setAudioThumb(const QUrl thumbPath = QUrl());
+    void setAudioThumb(const QList <QUrl> thumbPath = QList <QUrl>());
+    void setAudioStream(const QString &name);
+    void setRulerHeight(int height);
 
 signals:
     void positionChanged(int);
@@ -111,6 +115,7 @@ signals:
     void seekToKeyframe();
     void clipHasAVChanged();
     void clipNameChanged();
+    void clipStreamChanged();
     void clipTypeChanged();
     void clipIdChanged();
     void audioThumbChanged();
@@ -122,9 +127,10 @@ private:
     int m_zoneIn;
     int m_zoneOut;
     bool m_hasAV;
-    QUrl m_audioThumb;
+    QList <QUrl> m_audioThumb;
     QString m_markerComment;
     QString m_clipName;
+    QString m_clipStream;
     int m_clipType;
     int m_clipId;
     bool m_seekFinished;
