@@ -303,7 +303,7 @@ AudioGraphSpectrum::AudioGraphSpectrum(MonitorManager *manager, QWidget *parent)
     QAction *a = new QAction(i18n("Enable Audio Spectrum"), this);
     a->setCheckable(true);
     a->setChecked(KdenliveSettings::enableaudiospectrum());
-    if (KdenliveSettings::enableaudiospectrum()) {
+    if (KdenliveSettings::enableaudiospectrum() && isVisible()) {
         connect(m_manager, &MonitorManager::frameDisplayed, this, &ScopeWidget::onNewFrame, Qt::UniqueConnection);
     }
     connect(a, &QAction::triggered, this, &AudioGraphSpectrum::activate);
@@ -317,6 +317,17 @@ AudioGraphSpectrum::~AudioGraphSpectrum()
     delete m_filter;
 }
 
+void AudioGraphSpectrum::dockVisible(bool visible)
+{
+    if (KdenliveSettings::enableaudiospectrum())  {
+        if (!visible) {
+            disconnect(m_manager, &MonitorManager::frameDisplayed, this, &ScopeWidget::onNewFrame);
+        } else {
+            connect(m_manager, &MonitorManager::frameDisplayed, this, &ScopeWidget::onNewFrame);
+        }
+    }
+}
+
 void AudioGraphSpectrum::activate(bool enable)
 {
     if (enable) {
