@@ -21,10 +21,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "temporarydata.h"
 #include "doc/kdenlivedoc.h"
+#include "kdenlivesettings.h"
+#include "core.h"
+#include "bin/bin.h"
 
 #include <KLocalizedString>
 #include <KMessageBox>
-
+#include <KDiskFreeSpaceInfo>
 #include <QDesktopServices>
 #include <QFontMetrics>
 #include <QGridLayout>
@@ -37,6 +40,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QToolButton>
 #include <QTreeWidget>
 #include <QVBoxLayout>
+#include <QProgressBar>
+#include <QSpinBox>
 
 static QList<QColor> chartColors;
 
@@ -127,7 +132,7 @@ TemporaryData::TemporaryData(KdenliveDoc *doc, bool currentProjectOnly, QWidget
     m_grid->addWidget(m_proxySize, 1, 3);
     del = new QToolButton(this);
     del->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
-    connect(del, &QToolButton::clicked, this, &TemporaryData::deleteProxy);
+    connect(del, &QToolButton::clicked, this, &TemporaryData::deleteProjectProxy);
     del->setEnabled(false);
     m_grid->addWidget(del, 1, 4);
 
@@ -192,20 +197,31 @@ TemporaryData::TemporaryData(KdenliveDoc *doc, bool currentProjectOnly, QWidget
         m_proxies[i].append(QLatin1Char('*'));
     }
 
+    bool globalOnly = pCore->bin()->isEmpty();
     if (currentProjectOnly) {
         lay->addWidget(m_currentPage);
         auto *spacer = new QSpacerItem(1, 1, QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
         lay->addSpacerItem(spacer);
     } else {
         auto *tab = new QTabWidget(this);
-        tab->addTab(m_currentPage, i18n("Current Project"));
+        if (!globalOnly) {
+            tab->addTab(m_currentPage, i18n("Current Project"));
+        } else {
+            tab->setTabBarAutoHide(true);
+            delete m_currentPage;
+            m_currentPage = nullptr;
+        }
         m_globalPage = new QWidget(this);
         buildGlobalCacheDialog(minHeight);
         tab->addTab(m_globalPage, i18n("All Projects"));
         lay->addWidget(tab);
     }
     setLayout(lay);
-    updateDataInfo();
+    if (globalOnly && !currentProjectOnly) {
+        updateGlobalInfo();
+    } else {
+        updateDataInfo();
+    }
 }
 
 void TemporaryData::updateDataInfo()
@@ -225,13 +241,18 @@ void TemporaryData::updateDataInfo()
 
     preview = m_doc->getCacheDir(CacheProxy, &ok);
     if (ok) {
-        preview.setNameFilters(m_proxies);
-        const QFileInfoList fList = preview.entryInfoList();
-        KIO::filesize_t size = 0;
-        for (const QFileInfo &info : fList) {
-            size += (uint)info.size();
+        if (m_proxies.isEmpty()) {
+            // No proxies for this project
+            gotProxySize(0);
+        } else {
+            preview.setNameFilters(m_proxies);
+            const QFileInfoList fList = preview.entryInfoList();
+            KIO::filesize_t size = 0;
+            for (const QFileInfo &info : fList) {
+                size += (uint)info.size();
+            }
+            gotProxySize(size);
         }
-        gotProxySize(size);
     }
 
     preview = m_doc->getCacheDir(CacheAudio, &ok);
@@ -337,7 +358,7 @@ void TemporaryData::deletePreview()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache folder:\n%1", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the preview folder:\n%1\nPreview folder contains the timeline previews, and can be recreated with the source project.", dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("preview")) {
@@ -348,8 +369,101 @@ void TemporaryData::deletePreview()
     }
 }
 
-void TemporaryData::deleteProxy()
+void TemporaryData::deleteBackup()
 {
+    QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the backup folder:\n%1\nA copy of all your project files is kept in this folder for recovery in case of corruption.", backupFolder.absolutePath())) != KMessageBox::Continue) {
+        return;
+    }
+    if (backupFolder.dirName() == QLatin1String(".backup")) {
+        backupFolder.removeRecursively();
+        backupFolder.mkpath(QStringLiteral("."));
+        processBackupDirectories();
+    }
+}
+
+void TemporaryData::cleanBackup()
+{
+    QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
+    QFileInfoList files = backupFolder.entryInfoList(QDir::Files, QDir::Time);
+    QStringList oldFiles;
+    QDateTime current = QDateTime::currentDateTime();
+    for (const QFileInfo &f : files) {
+        if (f.lastModified().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
+            oldFiles << f.fileName();
+        }
+    }
+    if (oldFiles.isEmpty()) {
+        KMessageBox::information(this, i18n("No backup data older than %1 months was found.", KdenliveSettings::cleanCacheMonths()));
+        return;
+    }
+    if (KMessageBox::warningContinueCancelList(this, i18n("This will delete backup data for projects older than %1 months.", KdenliveSettings::cleanCacheMonths()), oldFiles) !=
+        KMessageBox::Continue) {
+        return;
+    }
+    if (backupFolder.dirName() == QLatin1String(".backup")) {
+        for (const QString &f : oldFiles) {
+            backupFolder.remove(f);
+        }
+        processBackupDirectories();
+    }
+}
+
+void TemporaryData::cleanCache()
+{
+    // Find empty dirs
+    QList<QTreeWidgetItem *> emptyDirs = m_listWidget->findItems(KIO::convertSize(0), Qt::MatchExactly, 2);
+    // Find old dirs
+    QTreeWidgetItem *root = m_listWidget->invisibleRootItem();
+    if (!root) {
+        return;
+    }
+    // Find old backup data ( older than 6 months )
+    KIO::filesize_t total = 0;
+    QDateTime current = QDateTime::currentDateTime();
+    int max = root->childCount();
+    for (int i = 0; i< max; i++) {
+        QTreeWidgetItem *child = root->child(i);
+        if (child->data(2, Qt::UserRole).toDateTime().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
+            emptyDirs << child;
+            total += child->data(1, Qt::UserRole).toLongLong();
+        }
+    }
+    QStringList folders;
+    for (auto *item : emptyDirs) {
+        folders << item->data(0, Qt::UserRole).toString();
+    }
+    if (folders.isEmpty()) {
+        KMessageBox::information(this, i18n("No cache data older than %1 months was found.", KdenliveSettings::cleanCacheMonths()));
+        return;
+    }
+
+    if (KMessageBox::warningContinueCancelList(this, i18n("This will delete cache data (%1) for missing projects or projects older than %2 months.", KIO::convertSize(total), KdenliveSettings::cleanCacheMonths()), folders) !=
+        KMessageBox::Continue) {
+        return;
+    }
+    const QString currentId = m_doc->getDocumentProperty(QStringLiteral("documentid"));
+    for (const QString &folder : folders) {
+        if (folder == currentId) {
+            // Trying to delete current project's tmp folder. Do not delete, but clear it
+            deleteCurrentCacheData();
+            continue;
+        }
+        if (!m_globalDir.exists(folder)) {
+            continue;
+        }
+        m_globalDir.remove(folder);
+    }
+    updateGlobalInfo();
+}
+
+
+void TemporaryData::deleteProjectProxy()
+{
+    if (m_proxies.isEmpty()) {
+        KMessageBox::information(this, i18n("No proxies found in the current project."));
+        return;
+    }
     bool ok = false;
     QDir dir = m_doc->getCacheDir(CacheProxy, &ok);
     if (!ok || dir.dirName() != QLatin1String("proxy")) {
@@ -357,7 +471,7 @@ void TemporaryData::deleteProxy()
     }
     dir.setNameFilters(m_proxies);
     QStringList files = dir.entryList(QDir::Files);
-    if (KMessageBox::warningContinueCancelList(this, i18n("Delete all project data in the cache proxy folder:\n%1", dir.absolutePath()), files) !=
+    if (KMessageBox::warningContinueCancelList(this, i18n("Delete all project data in the proxy folder:\n%1\nProxy folder contains the proxy clips for all your projects. This proxies can be recreated from the source clips.", dir.absolutePath()), files) !=
         KMessageBox::Continue) {
         return;
     }
@@ -375,7 +489,7 @@ void TemporaryData::deleteAudio()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache audio folder:\n%1", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache audio folder:\n%1\nThis folder contains the data for audio thumbnails in this project.", dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("audiothumbs")) {
@@ -392,7 +506,7 @@ void TemporaryData::deleteThumbs()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache thumbnail folder:\n%1", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache thumbnail folder:\n%1\nThis folder contains the data for video thumbnails in this project.", dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == QLatin1String("videothumbs")) {
@@ -409,7 +523,7 @@ void TemporaryData::deleteCurrentCacheData()
     if (!ok) {
         return;
     }
-    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in cache folder:\n%1", dir.absolutePath())) != KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete all data in the cache folder:\n%1\nCache folder contains the audio and video thumbnails, as well as timeline previews. All this data will be recreated on project opening.", dir.absolutePath())) != KMessageBox::Continue) {
         return;
     }
     if (dir.dirName() == m_doc->getDocumentProperty(QStringLiteral("documentid"))) {
@@ -431,11 +545,42 @@ void TemporaryData::openCacheFolder()
     QDesktopServices::openUrl(QUrl::fromLocalFile(dir.absolutePath()));
 }
 
+void TemporaryData::processBackupDirectories()
+{
+    QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
+    KIO::DirectorySizeJob *job = KIO::directorySize(QUrl::fromLocalFile(backupFolder.absolutePath()));
+    connect(job, &KIO::DirectorySizeJob::result, this, &TemporaryData::gotBackupSize);
+}
+
+void TemporaryData::processProxyDirectory()
+{
+    KIO::DirectorySizeJob *job = KIO::directorySize(QUrl::fromLocalFile(m_globalDir.absoluteFilePath(QStringLiteral("proxy"))));
+    connect(job, &KIO::DirectorySizeJob::result, this, &TemporaryData::gotProjectProxySize);
+}
+
+void TemporaryData::gotProjectProxySize(KJob *job)
+{
+    auto *sourceJob = static_cast<KIO::DirectorySizeJob *>(job);
+    KIO::filesize_t total = sourceJob->totalSize();
+    m_totalProxySize->setText(KIO::convertSize(total));
+}
+
+void TemporaryData::gotBackupSize(KJob *job)
+{
+    auto *sourceJob = static_cast<KIO::DirectorySizeJob *>(job);
+    KIO::filesize_t total = sourceJob->totalSize();
+    if (sourceJob->totalFiles() == 0) {
+        total = 0;
+    }
+    m_backupSize->setText(KIO::convertSize(total));
+}
+
 void TemporaryData::buildGlobalCacheDialog(int minHeight)
 {
-    auto *lay = new QGridLayout;
+    auto *lay = new QVBoxLayout;
+    auto *chartLay = new QHBoxLayout;
+    auto *treeLay = new QVBoxLayout;
     m_globalPie = new ChartWidget(this);
-    lay->addWidget(m_globalPie, 0, 0, 1, 1);
     m_listWidget = new QTreeWidget(this);
     m_listWidget->setColumnCount(3);
     m_listWidget->setHeaderLabels(QStringList() << i18n("Folder") << i18n("Size") << i18n("Date"));
@@ -443,8 +588,16 @@ void TemporaryData::buildGlobalCacheDialog(int minHeight)
     m_listWidget->setAlternatingRowColors(true);
     m_listWidget->setSortingEnabled(true);
     m_listWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    lay->addWidget(m_listWidget, 0, 1, 1, 4);
+    connect(m_listWidget, &QTreeWidget::itemDoubleClicked, [&](QTreeWidgetItem *item, int) {
+        QDesktopServices::openUrl(QUrl::fromLocalFile(m_globalDir.absoluteFilePath(item->data(0, Qt::UserRole).toString())));
+    });
+    treeLay->addWidget(m_listWidget);
+    chartLay->addLayout(treeLay);
+    chartLay->addWidget(m_globalPie);
+    chartLay->setStretch(0, 15);
+    chartLay->setStretch(1, 5);
     m_globalPage->setLayout(lay);
+    lay->addLayout(chartLay);
 
     // Total Cache data
     QPalette pal = palette();
@@ -453,29 +606,128 @@ void TemporaryData::buildGlobalCacheDialog(int minHeight)
     pal.setColor(QPalette::Window, chartColors.at(0));
     color->setPalette(pal);
     color->setAutoFillBackground(true);
-    lay->addWidget(color, 1, 1, Qt::AlignCenter);
+    auto *labelLay = new QHBoxLayout;
+    labelLay->addWidget(color);
     QLabel *lab = new QLabel(i18n("Total Cached Data"), this);
-    lay->addWidget(lab, 1, 2, 1, 1);
-    m_globalSize = new QLabel(this);
-    lay->addWidget(m_globalSize, 1, 3, 1, 1);
+    labelLay->addWidget(lab);
+    m_globalSize = new QLabel(i18n("Calculating..."), this);
+    labelLay->addWidget(m_globalSize);
+    // Cleanup button
+    auto *clean = new QToolButton(this);
+    clean->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-history")));
+    clean->setToolTip(i18n("Cleanup unused cache"));
+    connect(clean, &QToolButton::clicked, this, &TemporaryData::cleanCache);
+    labelLay->addStretch(10);
+    labelLay->addWidget(clean);
+    lay->addLayout(labelLay);
 
     // Selection
+    auto *labelLay2 = new QHBoxLayout;
     color = new QLabel(this);
     color->setFixedSize(minHeight, minHeight);
     pal.setColor(QPalette::Window, chartColors.at(1));
     color->setPalette(pal);
     color->setAutoFillBackground(true);
-    lay->addWidget(color, 2, 1, Qt::AlignCenter);
+    labelLay2->addWidget(color);
     lab = new QLabel(i18n("Selected Cached Data"), this);
-    lay->addWidget(lab, 2, 2, 1, 1);
-    m_selectedSize = new QLabel(this);
-    lay->addWidget(m_selectedSize, 2, 3, 1, 1);
-    m_globalDelete = new QPushButton(i18n("Delete selected cache"), this);
-    connect(m_globalDelete, &QPushButton::clicked, this, &TemporaryData::deleteSelected);
-    lay->addWidget(m_globalDelete, 2, 4, 1, 1);
+    labelLay2->addWidget(lab);
+    m_selectedSize = new QLabel(i18n("Calculating..."), this);
+    labelLay2->addWidget(m_selectedSize);
+
+    // Delete button
+    m_globalDelete = new QToolButton(this);
+    m_globalDelete->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
+    m_globalDelete->setToolTip(i18n("Delete selected cache"));
+    connect(m_globalDelete, &QToolButton::clicked, this, &TemporaryData::deleteSelected);
+    labelLay2->addStretch(10);
+    labelLay2->addWidget(m_globalDelete);
+    lay->addLayout(labelLay2);
+
+    QFrame *sep = new QFrame(this);
+    sep->setFrameShape(QFrame::HLine);
+    lay->addWidget(sep);
+
+    // Proxy data
+    QHBoxLayout *hLay = new QHBoxLayout;
+    lab = new QLabel(i18n("Total Proxy Data"), this);
+    hLay->addWidget(lab);
+    m_totalProxySize = new QLabel(i18n("Calculating..."), this);
+    hLay->addWidget(m_totalProxySize);
+    hLay->addStretch(10);
+    // Cleanup button
+    auto *clean3 = new QToolButton(this);
+    clean3->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-history")));
+    clean3->setToolTip(i18n("Cleanup old proxy files"));
+    connect(clean3, &QToolButton::clicked, this, &TemporaryData::cleanProxy);
+    hLay->addWidget(clean3);
+    auto *del2 = new QToolButton(this);
+    del2->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
+    del2->setToolTip(i18n("Delete all proxy clips"));
+    connect(del2, &QToolButton::clicked, this, &TemporaryData::deleteProxy);
+    hLay->addWidget(del2);
+    lay->addLayout(hLay);
+    bool ok = false;
+    QDir global = m_doc->getCacheDir(SystemCacheRoot, &ok);
+    QDir proxyFolder(global.absoluteFilePath(QStringLiteral("proxy")));
+    auto *url2 = new QLabel(QString("<a href='#'>%1</a>").arg(proxyFolder.absolutePath()), this);
+    url2->setToolTip(i18n("Click to open proxy folder"));
+    connect(url2, &QLabel::linkActivated, [proxyFolder]() {
+        QDesktopServices::openUrl(QUrl::fromLocalFile(proxyFolder.absolutePath()));
+    });
+    lay->addWidget(url2);
+
+    sep = new QFrame(this);
+    sep->setFrameShape(QFrame::HLine);
+    lay->addWidget(sep);
+
+    // Backup data
+    hLay = new QHBoxLayout;
+    lab = new QLabel(i18n("Total Backup Data"), this);
+    hLay->addWidget(lab);
+    m_backupSize = new QLabel(i18n("Calculating..."), this);
+    hLay->addWidget(m_backupSize);
+    hLay->addStretch(10);
+    // Cleanup button
+    auto *clean2 = new QToolButton(this);
+    clean2->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-history")));
+    clean2->setToolTip(i18n("Cleanup old backups"));
+    connect(clean2, &QToolButton::clicked, this, &TemporaryData::cleanBackup);
+    hLay->addWidget(clean2);
+    auto *del = new QToolButton(this);
+    del->setIcon(QIcon::fromTheme(QStringLiteral("trash-empty")));
+    del->setToolTip(i18n("Delete all backup data"));
+    connect(del, &QToolButton::clicked, this, &TemporaryData::deleteBackup);
+    hLay->addWidget(del);
+    lay->addLayout(hLay);
+    QDir backupFolder(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/.backup"));
+    auto *url = new QLabel(QString("<a href='#'>%1</a>").arg(backupFolder.absolutePath()), this);
+    url->setToolTip(i18n("Click to open backup folder"));
+    connect(url, &QLabel::linkActivated, [backupFolder]() {
+        QDesktopServices::openUrl(QUrl::fromLocalFile(backupFolder.absolutePath()));
+    });
+    lay->addWidget(url);
+
+    sep = new QFrame(this);
+    sep->setFrameShape(QFrame::HLine);
+    lay->addWidget(sep);
+
+    // Config cleanup age
+    hLay = new QHBoxLayout;
+    hLay->addWidget(new QLabel(i18n("Cleanup will delete data older than"), this));
+    QSpinBox *age = new QSpinBox(this);
+    age->setRange(1, 48);
+    age->setSuffix(i18np(" month", " months", KdenliveSettings::cleanCacheMonths()));
+    age->setValue(KdenliveSettings::cleanCacheMonths());
+    connect(age, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), [&, age] (int value) {
+        KdenliveSettings::setCleanCacheMonths(value);
+        age->setSuffix(i18np(" month", " months", KdenliveSettings::cleanCacheMonths()));
+    });
+    hLay->addWidget(age);
+    lay->addLayout(hLay);
+    lay->addStretch(10);
+
+    processBackupDirectories();
 
-    lay->setColumnStretch(4, 10);
-    lay->setRowStretch(0, 10);
     connect(m_listWidget, &QTreeWidget::itemSelectionChanged, this, &TemporaryData::refreshGlobalPie);
 }
 
@@ -494,7 +746,12 @@ void TemporaryData::updateGlobalInfo()
     m_globalDirectories.clear();
     m_processingDirectory.clear();
     m_globalDirectories = m_globalDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+    // These are some KDE cache dirs relater to Kdenlice that don't manage ourselves
+    m_globalDirectories.removeAll(QStringLiteral("knewstuff"));
+    m_globalDirectories.removeAll(QStringLiteral("attica"));
+    m_globalDirectories.removeAll(QStringLiteral("proxy"));
     m_globalDelete->setEnabled(!m_globalDirectories.isEmpty());
+    processProxyDirectory();
     processglobalDirectories();
     m_listWidget->blockSignals(false);
 }
@@ -569,9 +826,9 @@ void TemporaryData::refreshGlobalPie()
     int percent = m_totalGlobal <= 0 ? 0 : (int)(currentSize * 360 / m_totalGlobal);
     m_globalPie->setSegments(QList<int>() << 360 << percent);
     if (list.size() == 1 && list.at(0)->text(0) == m_doc->getDocumentProperty(QStringLiteral("documentid"))) {
-        m_globalDelete->setText(i18n("Clear current cache"));
+        m_globalDelete->setToolTip(i18n("Clear current cache"));
     } else {
-        m_globalDelete->setText(i18n("Delete selected cache"));
+        m_globalDelete->setToolTip(i18n("Delete selected cache"));
     }
 }
 
@@ -584,7 +841,7 @@ void TemporaryData::deleteSelected()
             folders << current->data(0, Qt::UserRole).toString();
         }
     }
-    if (KMessageBox::warningContinueCancelList(this, i18n("Delete the following cache folders from\n%1", m_globalDir.absolutePath()), folders) !=
+    if (KMessageBox::warningContinueCancelList(this, i18n("Delete the following cache folders from\n%1\nCache folders contains the audio and video thumbnails, as well as timeline previews. All this data will be recreated on project opening.", m_globalDir.absolutePath()), folders) !=
         KMessageBox::Continue) {
         return;
     }
@@ -595,12 +852,53 @@ void TemporaryData::deleteSelected()
             deleteCurrentCacheData();
             continue;
         }
-        QDir toRemove(m_globalDir.absoluteFilePath(folder));
-        toRemove.removeRecursively();
-        if (folder == QLatin1String("proxy")) {
-            // We deleted proxy folder, recreate it
-            toRemove.mkpath(QStringLiteral("."));
-        }
+        m_globalDir.remove(folder);
     }
     updateGlobalInfo();
 }
+
+void TemporaryData::deleteProxy()
+{
+    QDir proxies(m_globalDir.absoluteFilePath(QStringLiteral("proxy")));
+    if (proxies.dirName() != QLatin1String("proxy")) {
+        return;
+    }
+    if (KMessageBox::warningContinueCancel(this, i18n("Delete the proxy folder\n%1\nContains proxy clips for all your projects.", proxies.absolutePath())) !=
+        KMessageBox::Continue) {
+        return;
+    }
+    m_globalDir.remove(QStringLiteral("proxy"));
+    // We deleted proxy folder, recreate it
+    m_globalDir.mkpath(QStringLiteral("."));
+    processProxyDirectory();
+}
+
+void TemporaryData::cleanProxy()
+{
+    QDir proxies(m_globalDir.absoluteFilePath(QStringLiteral("proxy")));
+    if (proxies.dirName() != QLatin1String("proxy")) {
+        return;
+    }
+    QFileInfoList files = proxies.entryInfoList(QDir::Files, QDir::Time);
+    QStringList oldFiles;
+    QDateTime current = QDateTime::currentDateTime();
+    KIO::filesize_t size = 0;
+    for (const QFileInfo &f : files) {
+        if (f.lastModified().addMonths(KdenliveSettings::cleanCacheMonths()) < current) {
+            oldFiles << f.fileName();
+            size += f.size();
+        }
+    }
+    if (oldFiles.isEmpty()) {
+        KMessageBox::information(this, i18n("No proxy clips older than %1 months was found.", KdenliveSettings::cleanCacheMonths()));
+        return;
+    }
+    if (KMessageBox::warningContinueCancelList(this, i18n("Delete the following proxy clips (%1)\nProxy clips can be recreated on project opening.", KIO::convertSize(size)), oldFiles) !=
+        KMessageBox::Continue) {
+        return;
+    }
+    for (const QString &f : oldFiles) {
+        proxies.remove(f);
+    }
+    processProxyDirectory();
+}
