@@ -679,6 +679,11 @@ void ProjectManager::slotAutoSave()
             scene.replace(i.key(), i.value());
         }
     }
+    if (!scene.contains(QLatin1String("<track "))) {
+        // In some unexplained cases, the MLT playlist is corrupted and all tracks are deleted. Don't save in that case.
+        pCore->displayMessage(i18n("Project was corrupted, cannot backup. Please close and reopen your project file to recover last backup"), ErrorMessage);
+        return;
+    }
     m_project->slotAutoSave(scene);
     m_lastSave.start();
 }
