@@ -632,7 +632,7 @@ public:
      */
     virtual void adjustAssetRange(int clipId, int in, int out);
 
-    void requestClipReload(int clipId);
+    void requestClipReload(int clipId, int forceDuration = -1);
     void requestClipUpdate(int clipId, const QVector<int> &roles);
     /** @brief define current edit mode (normal, insert, overwrite */
     void setEditMode(TimelineMode::EditMode mode);
