@@ -44,6 +44,7 @@
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QQuickItem>
+#include <QActionGroup>
 #include <QUuid>
 #include <QMenu>
 #include <QFontDatabase>
@@ -53,6 +54,7 @@ const int TimelineWidget::comboScale[] = {1, 2, 4, 8, 15, 30, 50, 75, 100, 150,
 
 TimelineWidget::TimelineWidget(QWidget *parent)
     : QQuickWidget(parent)
+    , m_targetsGroup(nullptr)
 {
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(engine());
@@ -72,6 +74,7 @@ TimelineWidget::TimelineWidget(QWidget *parent)
     m_favEffects = new QMenu(i18n("Insert an effect..."), this);
     m_favCompositions = new QMenu(i18n("Insert a composition..."), this);
     installEventFilter(this);
+    m_targetsMenu = new QMenu(this);
 }
 
 TimelineWidget::~TimelineWidget()
@@ -184,6 +187,7 @@ void TimelineWidget::setModel(const std::shared_ptr<TimelineItemModel> &model, M
     connect(rootObject(), SIGNAL(showTimelineMenu()), this, SLOT(showTimelineMenu()));
     connect(rootObject(), SIGNAL(showRulerMenu()), this, SLOT(showRulerMenu()));
     connect(rootObject(), SIGNAL(showHeaderMenu()), this, SLOT(showHeaderMenu()));
+    connect(rootObject(), SIGNAL(showTargetMenu(int)), this, SLOT(showTargetMenu(int)));
     m_proxy->setRoot(rootObject());
     setVisible(true);
     loading = false;
@@ -260,6 +264,51 @@ void TimelineWidget::showHeaderMenu()
     m_headerMenu->popup(m_clickPos);
 }
 
+void TimelineWidget::showTargetMenu(int tid)
+{
+    int currentTargetStream;
+    if (tid == -1) {
+        // Called through shortcut
+        tid = m_proxy->activeTrack();
+        if (tid == -1) {
+            return;
+        }
+        if (m_proxy->clipTargets() < 2 || !model()->isAudioTrack(tid)) {
+            pCore->displayMessage(i18n("No available stream"), MessageType::InformationMessage);
+            return;
+        }
+        QVariant returnedValue;
+        QMetaObject::invokeMethod(rootObject(), "getActiveTrackStreamPos", Q_RETURN_ARG(QVariant, returnedValue));
+        m_clickPos = mapToGlobal(QPoint(5, y())) + QPoint(0, returnedValue.toInt());
+    }
+    QMap<int, QString> possibleTargets = m_proxy->getCurrentTargets(tid, currentTargetStream);
+    m_targetsMenu->clear();
+    if (m_targetsGroup) {
+        delete m_targetsGroup;
+    }
+    m_targetsGroup = new QActionGroup(this);
+    QMapIterator<int, QString> i(possibleTargets);
+    while (i.hasNext()) {
+        i.next();
+        QAction *ac = m_targetsMenu->addAction(i.value());
+        ac->setData(i.key());
+        m_targetsGroup->addAction(ac);
+        ac->setCheckable(true);
+        if (i.key() == currentTargetStream) {
+            ac->setChecked(true);
+        }
+    }
+    connect(m_targetsGroup, &QActionGroup::triggered, [this, tid] (QAction *action) {
+        int targetStream = action->data().toInt();
+        m_proxy->assignAudioTarget(tid, targetStream);
+    });
+    if (m_targetsMenu->isEmpty() || possibleTargets.isEmpty()) {
+        m_headerMenu->popup(m_clickPos);
+    } else {
+        m_targetsMenu->popup(m_clickPos);
+    }
+}
+
 void TimelineWidget::showRulerMenu()
 {
     m_guideMenu->clear();
@@ -359,7 +408,7 @@ void TimelineWidget::setTool(ProjectTool tool)
     rootObject()->setProperty("activeTool", (int)tool);
 }
 
-QPoint TimelineWidget::getTracksCount() const
+QPair<int, int> TimelineWidget::getTracksCount() const
 {
     return m_proxy->getTracksCount();
 }
